
<h1 align="center">Cogsworth</h1>
<p align="center">A Python package for performing self-consistent population synthesis and galactic dynamics simulations</p>
<p align="center">
  <a href='https://cogsworth.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/cogsworth/badge/?version=latest' alt='Documentation Status' />
</a>
  <br>
  <img width=500 src="https://user-images.githubusercontent.com/21990332/194442782-49afc013-2c53-4638-bcb7-c0970319c2bd.png">
</p>
